package org.apache.commons.lang3.time;

package .tmp;

import java.util.Calendar;
import java.util.Locale;
import java.util.Map;
import org.apache.commons.lang3.LocaleUtils;
import org.apache.commons.lang3.time.FastDateParser;

class CaseInsensitiveTextStrategy extends FastDateParser.PatternStrategy {
  private final int field;
  
  final Locale locale;
  
  private final Map<String, Integer> lKeyValues;
  
  CaseInsensitiveTextStrategy(int field, Calendar definingCalendar, Locale locale) {
    this.field = field;
    this.locale = LocaleUtils.toLocale(locale);
    StringBuilder regex = new StringBuilder();
    regex.append("((?iu)");
    this.lKeyValues = FastDateParser.access$600(definingCalendar, locale, field, regex);
    regex.setLength(regex.length() - 1);
    regex.append(")");
    createPattern(regex);
  }
  
  void setCalendar(FastDateParser parser, Calendar calendar, String value) {
    String lowerCase = value.toLowerCase(this.locale);
    Integer iVal = this.lKeyValues.get(lowerCase);
    if (iVal == null)
      iVal = this.lKeyValues.get(lowerCase + '.'); 
    calendar.set(this.field, iVal.intValue());
  }
  
  public String toString() {
    return "CaseInsensitiveTextStrategy [field=" + this.field + ", locale=" + this.locale + ", lKeyValues=" + this.lKeyValues + ", pattern=" + this.pattern + "]";
  }
}
